==================
networking-fujitsu
==================

FUJITSU plugins/drivers for OpenStack Neutron.

* Free software: Apache license
* Source: https://git.openstack.org/cgit/openstack/networking-fujitsu
* Bugs: https://bugs.launchpad.net/networking-fujitsu

ML2 driver for FUJITSU Converged Fabric Switch(CFX2000)
-------------------------------------------------------

* For more detail, please refer https://github.com/openstack/networking-fujitsu/blob/master/doc/source/ml2_cfab.rst.

.. include:: ml2_cfab.rst

ML2 driver for FUJITSU FOS Switch(Draft)
----------------------------------------

* For more detail, please refer https://github.com/openstack/networking-fujitsu/blob/master/doc/source/ml2_fossw.rst.

.. include:: ml2_fossw.rst
